@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from vcert.common import Policy as Cit, AppDetails
+from vcert.common import Policy as Cit, AppDetails, KeyType
 from vcert.errors import VenafiError
 from vcert.policy import RPA, DEFAULT_CA
 from vcert.policy.policy_spec import Policy, Subject, KeyPair, DefaultSubject, DefaultKeyPair, PolicySpecification, \
@@ -41,8 +41,13 @@ def build_policy_spec(cit, ca_info):
 
     ps = PolicySpecification()
     p = Policy()
-    p.domains = cit.SubjectCRegexes if len(cit.SubjectCRegexes) > 0 else None
     p.wildcard_allowed = is_wildcard_allowed(cit.SubjectCNRegexes)
+    if len(cit.SubjectCNRegexes) > 0:
+        domains = convert_to_string(cit.SubjectCNRegexes, p.wildcard_allowed)
+        p.domains = domains
+    else:
+        p.domains = None
+
     if cit.validity_period:
         # getting days in format P#D
         days = cit.validity_period[1:len(cit.validity_period)-1]
@@ -82,7 +87,9 @@ def build_policy_spec(cit, ca_info):
         for allowed_kt in cit.key_types:
             kt = allowed_kt.key_type
             kl = allowed_kt.option
-            key_types.append(kt)
+            # Only include one instance of the KeyType
+            if kt not in key_types:
+                key_types.append(kt)
             key_sizes.append(kl)
         create_kp = True
         kp.key_types = key_types
@@ -152,7 +159,8 @@ def validate_policy_spec(policy_spec):
             if len(policy_spec.policy.key_pair.key_types) > 1:
                 raise VenafiError('Key Type values exceeded. Only one Key Type is allowed by Venafi Cloud')
 
-            if policy_spec.policy.key_pair.key_types and policy_spec.policy.key_pair.key_types[0] != 'RSA':
+            if policy_spec.policy.key_pair.key_types \
+                    and policy_spec.policy.key_pair.key_types[0].lower() != KeyType.RSA:
                 raise VenafiError('Key Type [%s] is not supported by Venafi Cloud' % p.key_pair.key_types[0])
 
             if len(policy_spec.policy.key_pair.rsa_key_sizes) > 0:
@@ -380,9 +388,9 @@ def build_cit_request(ps, ca_details):
 
     key_types = dict()
     if ps.policy and ps.policy.key_pair and len(ps.policy.key_pair.key_types) > 0:
-        key_types['keyType'] = ps.policy.key_pair.key_types[0]
+        key_types['keyType'] = ps.policy.key_pair.key_types[0].upper()
     else:
-        key_types['keyType'] = 'RSA'
+        key_types['keyType'] = KeyType.RSA.upper()
 
     if ps.policy and ps.policy.key_pair and len(ps.policy.key_pair.rsa_key_sizes) > 0:
         key_types['keyLengths'] = ps.policy.key_pair.rsa_key_sizes
@@ -430,6 +438,10 @@ def build_cit_request(ps, ca_details):
     return request
 
 
+domain_regex = '[a-z]{1}[a-z0-9.-]*\\.'
+domain_regex_wildcard = '[*a-z]{1}[a-z0-9.-]*\\.'
+
+
 def convert_to_regex(domains, wildcard_allowed):
     """
     :param list[str] domains:
@@ -440,13 +452,29 @@ def convert_to_regex(domains, wildcard_allowed):
     for d in domains:
         current = d.replace('.', '\\.')
         if wildcard_allowed:
-            current = "[*a-z]{1}[a-z0-9.-]*\\." + current
+            current = domain_regex_wildcard + current
         else:
-            current = "[a-z]{1}[a-z0-9.-]*\\." + current
+            current = domain_regex + current
         regex_list.append(current)
     return regex_list
 
 
+def convert_to_string(regexes, wildcard_allowed):
+    """
+    :param list[str] regexes:
+    :param bool wildcard_allowed:
+    :return list[str]:
+    """
+    pattern = domain_regex_wildcard if wildcard_allowed else domain_regex
+    string_list = []
+    for r in regexes:
+        if r.startswith(pattern):
+            r = r.replace(pattern, '')
+        r = r.replace('\\.', '.')
+        string_list.append(r)
+    return string_list
+
+
 def is_wildcard_allowed(san_regexes):
     """
     :param list[str] san_regexes:
